package mediaMarkt;


public class Electrodomestico {

	//Atributos han de ser private, excepto en casos muy concretos
	private String tipo;
	private double precioBase;
	private String color;
	private char consumoEnergetico;
	private String marca;


	public Electrodomestico(String tipo, double precioBase, String color, char consumoEnergetico, String marca) {
		//super(); No es necesario si no hay una herencia de clases
		this.tipo = tipo;
		this.precioBase = precioBase;
		this.color = color.toUpperCase(); //Forzamos mayúsculas para facilitar posterior validación
		this.consumoEnergetico = consumoEnergetico;
		this.marca = marca.toUpperCase(); //Forzamos mayúsculas para facilitar posterior validación
	}
	//Solo se detalla el precio
	public Electrodomestico(double precioBase) {
		//super(); No es necesario si no hay una herencia de clases
		tipo = "";
		this.precioBase = precioBase;
		color = "";
		consumoEnergetico = ' ';
		marca = "";
	}

	public String getTipo() {
		return tipo;
	}

	public void setTipo(String tipo) {
		this.tipo = tipo;
	}

	public double getPrecioBase() {
		return precioBase;
	}

	public void setPrecioBase(double precioBase) {
		this.precioBase = precioBase;
	}

	public String getColor() {
		return color;
	}

	public void setColor(String color) {
		this.color = color;
	}

	public char getConsumoEnergetico() {
		return consumoEnergetico;
	}

	public void setConsumoEnergetico(char consumoEnergetico) {
		this.consumoEnergetico = consumoEnergetico;
	}

	public String getMarca() {
		return marca;
	}

	public void setMarca(String marca) {
		this.marca = marca;
	}

	@Override
	public String toString() {
		//Solo imprimimos valores que no estén vacíos/nulos
		StringBuilder valores = new StringBuilder();
		if (!tipo.isEmpty())
			valores.append("Tipo: " + tipo);
		if (precioBase > 0)
			valores.append(String.format("\nPrecio Base: %.2f", precioBase));
		if (!color.isEmpty())
			valores.append("\nColor: " + color);
		if (consumoEnergetico != ' ')
			valores.append("Consumo Energético: " + consumoEnergetico);
		if (!marca.isEmpty())
			valores.append("Marca: " + marca);

		return valores.toString();
	}

	public boolean validarColor() {
		switch (color) {
		case "BLANCO":
		case "NEGRO":
		case "GRIS":
			return true;
		default:
			System.out.println("Color no valido. Eliga entre BLANCO, NEGRO o GRIS\n");
			return false;
		}
	}
	
	public boolean validarConsumo() {
		switch(consumoEnergetico) {
		case 'A':
		case 'a':
		case 'B':
		case 'b':
		case 'C':
		case 'c':
		case 'D':
		case 'd':
		case 'E':
		case 'e':
		case 'F':
		case 'f':
			return true;
		default:
			System.out.println("Consumo inválido. Elija entre A, B, C, D, E o F\n");
			return false;
		}
	}
	
	public boolean validarMarca() {
		switch(marca) {
		case "ZANUSSI":
		case "TEKA":
		case "SIEMENS":
		case "LG":
			return true;
		default:
			System.out.println("Marca desconocida. Elija entre ZANUSSI, TEKA, SIEMENS o LG\n");
			return false;
		}
	}
	
	public double precioFinal() {
		
		double precioFinal = precioBase;
		
		//Impuesto por consumo
		switch(consumoEnergetico) {
		case 'A':
		case 'a':
			//Impuesto 0
			break;
		case 'B':
		case 'b':
			precioFinal += 25;
			break;
		case 'C':
		case 'c':
			precioFinal += 100;
			break;
		case 'D':
		case 'd':
			precioFinal += 120;
			break;
		case 'E':
		case 'e':
			precioFinal += 150;
			break;
		case 'F':
		case 'f':
			precioFinal += 200;
		}
		
		//Impuesto por marca
		switch(marca) {
		case "ZANUSSI":
			precioFinal += 25;
			break;
		case "TEKA":
			precioFinal += 10;
			break;
		case "SIEMENS":
			precioFinal += 30;
			break;
		case "LG":
			precioFinal += 100;
		}
		
		//21% IVA
		return precioFinal * 1.21;
	}

	/*public void comprobarConsumoEnergetico(char letra) {
		boolean correcto = false;
		try {
			switch(letra) {
			case 'A':
				correcto = true;
				this.precioBase = precioBase + 0;
				break;
			case 'B':
				correcto = true;
				this.precioBase = precioBase + 25;
				break;
			case 'C':
				correcto = true;
				this.precioBase = precioBase + 100;
				break;
			case 'D':
				correcto= true;
				this.precioBase = precioBase + 120;
				break;
			case 'E':
				correcto = true;
				this.precioBase = precioBase + 150;
				break;
			case 'F':
				correcto = true;
				this.precioBase = precioBase + 200;
				break;
			}
		}catch(java.util.InputMismatchException err) {
			System.out.println("\nIntroduce un valor válido (A, B, C, D, E, F):");
		}
		if(correcto) {
			this.consumoEnergetico = letra;
		}
	}*/

	/*
	public void comprobarMarca(String marca) {
		boolean correcto = false;
		try {
			switch(marca) {
			case "Zanussi":
				correcto = true;
				this.precioBase = precioBase + 0;
				break;
			case "Teka":
				correcto = true;
				this.precioBase = precioBase + 25;
				break;
			case "Siemens":
				correcto = true;
				this.precioBase = precioBase + 100;
				break;
			case "LG":
				correcto= true;
				this.precioBase = precioBase + 120;
				break;
			}
		}catch(java.util.InputMismatchException err) {
			System.out.println("\nIntroduce un valor válido (Zanussi, Teka, Siemens, LG):");
		}
		if(correcto) {
			this.marca = marca;
		}
	}*/

	/*
	public void comprobarColor(String color) {
		boolean correcto = false;
		do {
		if(color == "Negro" || color == "Blanco"
			|| color == "Gris") {
			this.color = color;
		} else {
			System.out.println("Ese color no está en stock porque es feismo.\nElige entre blanco, negro o gris");
			correcto = true;
		}		
	}while(correcto == true);
	}*/

	/*
	public double precioFinal() {
		double iva = precioBase * 0.21;
		return precioBase + iva;
	}*/

}

